@@ -1,6 +1,7 @@
 # This layout exists, specifically to make poetry+extras work
 def main():
-    from .commands import cli, cluster, replica, sentinel, standalone
+    from .commands import (cli, cluster, enterprise, replica, sentinel,
+                           standalone)
 
     cli.group(standalone.standalone).add_command(standalone.create)
 
@@ -10,6 +11,8 @@ def main():
 
     cli.group(cluster.cluster).add_command(cluster.create)
 
+    cli.group(enterprise.enterprise).add_command(enterprise.create)
+
     cli()
 
 
