@@ -2,9 +2,9 @@ import sys
 
 import click
 
+from ..composer import DockerComposeWrapper
 from ..env import ClusterHandler, _default_options
 from ..util import free_ports
-from ..composer import DockerComposeWrapper
 from . import defaultenvname
 
 
@@ -68,6 +68,18 @@ def cluster():
     default=_default_options["_cluster_replicas"],
     type=int,
 )
+@click.option(
+    "--generate-only",
+    help="set, to only generate the configurations, and not run them",
+    is_flag=True,
+    default=False,
+)
+@click.option(
+    "--starting-port",
+    help="If set to a value other than -1 (default), assign ports starting at the specified port",
+    type=int,
+    default=-1,
+)
 @click.pass_context
 def create(
     ctx,
@@ -79,6 +91,8 @@ def create(
     mounts,
     redisopts,
     replicas,
+    generate_only,
+    starting_port,
 ):
     """create and start a new environment"""
 
@@ -92,8 +106,8 @@ def create(
         sys.stderr.write("There must be fewer replicas than nodes.\n")
         sys.exit(3)
 
-    ports = free_ports(nodes, cluster=True)
-    g = ClusterHandler(ctx.obj.get("DESTDIR"), name)
+    ports = free_ports(nodes, cluster=True, starting_port=starting_port)
+    g = ClusterHandler(ctx.obj.get("DESTDIR"), name, generate_only=generate_only)
     w = DockerComposeWrapper(g)
 
     cfg = g.gen_config(ports, redisopts)
@@ -105,6 +119,7 @@ def create(
         mounts,
         ports,
         replicas,
+        starting_port,
     )
 
     if force:
