@@ -81,6 +81,18 @@ def replica():
     default="172.0.0.1",
     help="Set, to override the  docker ip (mostly used with the replicaof options)",
 )
+@click.option(
+    "--generate-only",
+    help="set, to only generate the configurations, and not run them",
+    is_flag=True,
+    default=False,
+)
+@click.option(
+    "--starting-port",
+    help="If set to a value other than -1 (default), assign ports starting at the specified port",
+    type=int,
+    default=-1,
+)
 @click.pass_context
 def create(
     ctx,
@@ -95,6 +107,8 @@ def create(
     redisopts,
     replicaof,
     docker_ip,
+    generate_only,
+    starting_port,
 ):
     """create and start a new environment"""
     if replicaof == -1:
@@ -102,10 +116,9 @@ def create(
             sys.stderr.write("To configure replicas, at least two nodes are needed.\n")
             sys.exit(3)
 
-    g = ReplicaHandler(ctx.obj.get("DESTDIR"), name)
+    g = ReplicaHandler(ctx.obj.get("DESTDIR"), name, generate_only=generate_only)
     w = DockerComposeWrapper(g)
     sp = g.gen_spec(
-        name,
         nodes,
         version,
         image,
@@ -115,6 +128,7 @@ def create(
         redisopts,
         replicaof,
         docker_ip,
+        starting_port,
     )
 
     if force:
