@@ -86,6 +86,18 @@ def sentinel():
     default="172.0.0.1",
     help="Set, to override the docker ip (i.e if you want to use an existing redis)",
 )
+@click.option(
+    "--generate-only",
+    help="set, to only generate the configurations, and not run them",
+    is_flag=True,
+    default=False,
+)
+@click.option(
+    "--starting-port",
+    help="If set to a value other than -1 (default), assign ports starting at the specified port",
+    type=int,
+    default=-1,
+)
 @click.pass_context
 def create(
     ctx,
@@ -101,6 +113,8 @@ def create(
     sentinelopts,
     redisopts,
     docker_ip,
+    generate_only,
+    starting_port,
 ):
     """create and start a new environment"""
 
@@ -110,8 +124,8 @@ def create(
         )
         sys.exit(3)
 
-    ports = free_ports(nodes)
-    g = SentinelHandler(ctx.obj.get("DESTDIR"), name)
+    ports = free_ports(nodes, starting_port=starting_port)
+    g = SentinelHandler(ctx.obj.get("DESTDIR"), name, generate_only=generate_only)
     w = DockerComposeWrapper(g)
 
     cfg = g.gen_config(
@@ -123,7 +137,6 @@ def create(
     )
 
     sp = g.gen_spec(
-        name=name,
         nodes=nodes,
         version=version,
         image=image,
@@ -131,6 +144,7 @@ def create(
         redisconf=redisconf,
         redisopts=redisopts,
         ports=ports,
+        starting_port=starting_port,
     )
 
     if force:
