@@ -2,8 +2,8 @@ import sys
 
 import click
 
-from ..env import STANDALONE_TYPE, StandaloneHandler, _default_options
 from ..composer import DockerComposeWrapper
+from ..env import STANDALONE_TYPE, StandaloneHandler, _default_options
 from . import defaultenvname
 
 
@@ -69,6 +69,18 @@ def standalone():
     multiple=True,
     type=str,
 )
+@click.option(
+    "--generate-only",
+    help="set, to only generate the configurations, and not run them",
+    is_flag=True,
+    default=False,
+)
+@click.option(
+    "--starting-port",
+    help="If set to a value other than -1 (default), assign ports starting at the specified port",
+    type=int,
+    default=-1,
+)
 @click.pass_context
 def create(
     ctx,
@@ -81,14 +93,15 @@ def create(
     conffile,
     ipv6,
     redisopts,
+    generate_only,
+    starting_port,
 ):
     """create and start a new environment"""
 
-    g = StandaloneHandler(ctx.obj.get("DESTDIR"), name)
+    g = StandaloneHandler(ctx.obj.get("DESTDIR"), name, generate_only=generate_only)
 
     w = DockerComposeWrapper(g)
     sp = g.gen_spec(
-        name,
         nodes,
         version,
         image,
@@ -96,6 +109,7 @@ def create(
         conffile,
         ipv6,
         redisopts,
+        starting_port,
     )
     if force:
         try:
